@@ -5,8 +5,7 @@ drop outdated weblib dependency.
 """
 import re
 from html.entities import name2codepoint
-from re import Match
-from typing import List, Optional, Union, cast  # noqa: PEA001
+from typing import List, Match, Optional, Union, cast  # noqa: PEA001
 
 import lxml.html
 from lxml.etree import _Element
@@ -104,12 +103,9 @@ def decode_entities(html: str) -> str:
 
 def render_html(node: _Element) -> str:
     """Render Element node."""
-    return cast(
-        str,
-        lxml.html.tostring(cast(lxml.html.HtmlElement, node), encoding="utf-8").decode(
-            "utf-8"
-        ),
-    )
+    return lxml.html.tostring(
+        cast(lxml.html.HtmlElement, node), encoding="utf-8"
+    ).decode("utf-8")
 
 
 def get_node_text(
